@@ -77,6 +77,7 @@ class UndercloudConfig(StandaloneConfig):
             mistral=False,
             nova=False,
             novajoin=False,
+            swift=True,
             tempest=True,
             telemetry=False,
             validations=True,
@@ -224,12 +225,6 @@ class UndercloudConfig(StandaloneConfig):
                        default=1500,
                        help=_('MTU to use for the local_interface.')
                        ),
-            cfg.StrOpt('docker_bip',
-                       default='--bip=172.31.0.1/24',
-                       deprecated_for_removal=True,
-                       help=_('Docker bridge IP for the undercloud.')
-                       ),
-
             cfg.StrOpt('inspection_interface',
                        default='br-ctlplane',
                        deprecated_name='discovery_interface',
@@ -282,13 +277,6 @@ class UndercloudConfig(StandaloneConfig):
                         default=True,
                         help=_('Enable or disable SELinux during the '
                                'deployment.')),
-            cfg.BoolOpt('undercloud_update_packages',
-                        default=False,
-                        help=_(
-                            'Whether to update packages during the Undercloud '
-                            'install. This is a no-op for containerized '
-                            'undercloud.')
-                        ),
             cfg.StrOpt('ipa_otp',
                        default='',
                        help=_(
@@ -315,12 +303,6 @@ class UndercloudConfig(StandaloneConfig):
                             'Whether to clean overcloud nodes (wipe the hard '
                             'drive) between deployments and after the '
                             'introspection.')),
-            cfg.BoolOpt('upgrade_cleanup',
-                        default=False,
-                        help=_(
-                            '(Experimental) Whether to clean undercloud rpms '
-                            'after an upgrade to a containerized '
-                            'undercloud.')),
             cfg.ListOpt('enabled_hardware_types',
                         default=['ipmi', 'redfish', 'ilo', 'idrac'],
                         help=_('List of enabled bare metal hardware types '
@@ -374,13 +356,6 @@ class UndercloudConfig(StandaloneConfig):
                        help=(_('Ironic network interface implementation to '
                                'use by default.'))
                        ),
-            cfg.StrOpt('auth_token_lifetime',
-                       default=14400,
-                       help=(_(
-                             'Authentication token expiration time in '
-                             'seconds. Note reducing this can have impacts on '
-                             'long running undercloud processes.'))
-                       ),
         ]
         return self.sort_opts(_base_opts + _opts)
 
