@@ -26,7 +26,6 @@ class TestUndercloudConfig(base.TestCase):
     def test_get_base_opts(self):
         ret = self.config.get_base_opts()
         expected = ['additional_architectures',
-                    'auth_token_lifetime',
                     'certificate_generation_ca',
                     'clean_nodes',
                     'cleanup',
@@ -38,7 +37,6 @@ class TestUndercloudConfig(base.TestCase):
                     'custom_env_files',
                     'deployment_user',
                     'discovery_default_driver',
-                    'docker_bip',
                     'enable_node_discovery',
                     'enable_routed_networks',
                     'enable_swift_encryption',
@@ -77,15 +75,12 @@ class TestUndercloudConfig(base.TestCase):
                     'undercloud_ntp_servers',
                     'undercloud_public_host',
                     'undercloud_service_certificate',
-                    'undercloud_timezone',
-                    'undercloud_update_packages',
-                    'upgrade_cleanup']
+                    'undercloud_timezone']
         self.assertEqual(expected, [x.name for x in ret])
 
     def test_get_opts(self):
         ret = self.config.get_opts()
         expected = ['additional_architectures',
-                    'auth_token_lifetime',
                     'certificate_generation_ca',
                     'clean_nodes',
                     'cleanup',
@@ -97,7 +92,6 @@ class TestUndercloudConfig(base.TestCase):
                     'custom_env_files',
                     'deployment_user',
                     'discovery_default_driver',
-                    'docker_bip',
                     'enable_cinder',
                     'enable_ironic',
                     'enable_ironic_inspector',
@@ -106,6 +100,7 @@ class TestUndercloudConfig(base.TestCase):
                     'enable_nova',
                     'enable_novajoin',
                     'enable_routed_networks',
+                    'enable_swift',
                     'enable_swift_encryption',
                     'enable_telemetry',
                     'enable_tempest',
@@ -146,9 +141,7 @@ class TestUndercloudConfig(base.TestCase):
                     'undercloud_ntp_servers',
                     'undercloud_public_host',
                     'undercloud_service_certificate',
-                    'undercloud_timezone',
-                    'undercloud_update_packages',
-                    'upgrade_cleanup']
+                    'undercloud_timezone']
         self.assertEqual(expected, [x.name for x in ret])
 
     def test_get_subnet_opts(self):
@@ -177,6 +170,7 @@ class TestUndercloudConfig(base.TestCase):
                     'enable_nova': False,
                     'enable_novajoin': False,
                     'enable_telemetry': False,
+                    'enable_swift': True,
                     'enable_tempest': True,
                     'enable_validations': True,
                     'enable_zaqar': False}
