@@ -21,6 +21,7 @@ import os
 from cliff import command
 from osc_lib.i18n import _
 
+from tripleoclient.constants import DEFAULT_HEAT_CONTAINER
 from tripleoclient import exceptions
 from tripleoclient import heat_launcher
 
@@ -94,10 +95,9 @@ class LaunchHeat(command.Command):
         parser.add_argument(
             '--heat-container-image', metavar='<HEAT_CONTAINER_IMAGE>',
             dest='heat_container_image',
-            default='tripleomaster/centos-binary-heat-all:current-tripleo',
+            default=DEFAULT_HEAT_CONTAINER,
             help=_('The container image to use when launching the heat-all '
-                   'process. Defaults to: '
-                   'tripleomaster/centos-binary-heat-all:current-tripleo')
+                   'process. Defaults to: {}'.format(DEFAULT_HEAT_CONTAINER))
         )
         parser.add_argument(
             '--heat-native',
